==> SQLExchange 1.0.2.1.zip: SQLExchange 1.0.2.1/SQLEServer/Resources/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by SQLEServer.rc
//
#define IDS_TITLECAPTION                1
#define IDS_FILEVERSION                 2
#define IDS_APPCOPYRIGHT                3
#define IDS_REGISTRYKEY                 4
#define IDI_MAINICON                    101
#define IDI_MAIN                        101
#define IDD_MAIN                        102
#define IDR_SERVERDLGMENU               103
#define IDD_SECURITYTAB                 104
#define IDD_SERVERTAB                   105
#define IDD_DROPBADPACKETS              105
#define IDI_ADVANCEDTAB                 106
#define IDI_GENERALTAB                  107
#define IDD_CLIENTDBSTAB                108
#define IDI_SECURITYTAB                 108
#define IDI_TRAYICON                    109
#define IDI_SERVERTAB                   112
#define IDI_SQLIMPORTTAB                113
#define IDI_WPINDEXTAB                  114
#define IDB_SPLASH                      117
#define IDD_SPLASH                      135
#define IDD_WPINDEXDBTAB                136
#define IDD_SERVER                      137
#define IDD_GENERALTAB                  138
#define IDD_MAIN1                       139
#define IDD_MONITOR                     139
#define IDC_TEXTBOX                     1000
#define IDC_OK                          1001
#define IDC_USAGEGRAPH                  1001
#define IDC_CANCEL                      1002
#define IDC_STATICTEXT                  1003
#define IDC_LOGLIST                     1004
#define IDD_NEXTCLIENTID                1005
#define IDC_LISTENPORT                  1006
#define IDC_MAXCONNECTS                 1007
#define IDC_TCPLOOPDELAY                1008
#define IDC_AUTHSTRING                  1019
#define IDC_PRODUCTTEXT                 1019
#define IDC_BASECOMMKEY                 1020
#define IDC_VERSIONTEXT                 1020
#define IDC_AUTHKEY                     1020
#define IDC_LOCALCRYPTKEY               1021
#define IDC_OSTEXT                      1021
#define IDC_AUTHKEY2                    1021
#define IDC_ENCRYPTKEYLEN               1021
#define IDC_ADMINPASSWORD1              1022
#define IDC_MEMORYTEXT                  1022
#define IDC_SPLASHPROGRESS              1023
#define IDC_ADMINPASSWORD2              1023
#define IDC_PROCESORSTEXT               1023
#define IDC_BUILDDATETEXT               1024
#define IDC_SQLDRIVER                   1025
#define IDC_SQLDATABASE                 1026
#define IDC_BROWSEBUTTON                1026
#define IDC_SQLUSERNAME                 1027
#define IDC_SQLPASSWORD                 1028
#define IDC_TEMPDIR                     1029
#define IDC_VERSIONTAG                  1030
#define IDC_SQLSERVER                   1031
#define IDC_CHECK1                      1032
#define IDC_USENTFIBERS                 1032
#define IDC_STATICFRAME                 1038
#define IDC_CONNECTIONS                 1039
#define IDC_TOTALCONNECTS               1040
#define IDC_WARNINGS                    1041
#define IDC_ERRORS                      1042
#define IDC_CLIENTTHREADBOOST           3000
#define IDC_DROPBADPACKETS              3001
#define IDC_USEPACKEMODE                3002
#define IDC_PROCESSTBOOTS               4000
#define ID_SERVER_START                 40001
#define ID_SERVER_STOP                  40002
#define ID_SERVER_SETTINGS              40003
#define ID_SERVkkkSTOP                  40003
#define ID_MONITOR_CONNECTIONS          40005
#define ID_SERVER_CLOSE                 40006
#define ID_HELP_ABOUT                   40007
#define ID_SPECIAL_DEBUGMODE            40008
#define ID_SPECIAL_OPENCONSOLE          40009
#define ID_HELP_VERSION                 40010

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        103
#define _APS_NEXT_COMMAND_VALUE         40007
#define _APS_NEXT_CONTROL_VALUE         1006
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> SQLExchange 1.0.3.2.zip: SQLExchange 1.0.3.2/SQLEServer/Resources/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by SQLEServer.rc
//
#define IDS_TITLECAPTION                1
#define IDS_FILEVERSION                 2
#define IDS_APPCOPYRIGHT                3
#define IDS_REGISTRYKEY                 4
#define IDI_MAINICON                    101
#define IDI_MAIN                        101
#define IDD_MAIN                        102
#define IDR_SERVERDLGMENU               103
#define IDD_SECURITYTAB                 104
#define IDD_SERVERTAB                   105
#define IDD_DROPBADPACKETS              105
#define IDI_ADVANCEDTAB                 106
#define IDI_GENERALTAB                  107
#define IDD_CLIENTDBSTAB                108
#define IDI_SECURITYTAB                 108
#define IDI_TRAYICON                    109
#define IDI_SERVERTAB                   112
#define IDI_SQLIMPORTTAB                113
#define IDI_WPINDEXTAB                  114
#define IDB_SPLASH                      117
#define IDD_SPLASH                      135
#define IDD_WPINDEXDBTAB                136
#define IDD_SERVER                      137
#define IDD_GENERALTAB                  138
#define IDD_MAIN1                       139
#define IDD_MONITOR                     139
#define IDD_MAIN2                       140
#define IDD_CREATENEWDB                 140
#define IDC_TEXTBOX                     1000
#define IDC_OK                          1001
#define IDC_USAGEGRAPH                  1001
#define IDC_CANCEL                      1002
#define IDC_STATICTEXT                  1003
#define IDC_LOGLIST                     1004
#define IDD_NEXTCLIENTID                1005
#define IDC_LISTENPORT                  1006
#define IDC_PREPARE                     1006
#define IDC_MAXCONNECTS                 1007
#define IDC_CREATE                      1007
#define IDC_TCPLOOPDELAY                1008
#define IDC_BACKUPNAME                  1009
#define IDC_NEWDBNAME                   1010
#define IDC_DBO                         1011
#define IDC_BACKUPNAME2                 1013
#define IDC_DATAFILELOC                 1013
#define IDC_AUTHSTRING                  1019
#define IDC_PRODUCTTEXT                 1019
#define IDC_BASECOMMKEY                 1020
#define IDC_VERSIONTEXT                 1020
#define IDC_AUTHKEY                     1020
#define IDC_LOCALCRYPTKEY               1021
#define IDC_OSTEXT                      1021
#define IDC_AUTHKEY2                    1021
#define IDC_ENCRYPTKEYLEN               1021
#define IDC_ADMINPASSWORD1              1022
#define IDC_MEMORYTEXT                  1022
#define IDC_SPLASHPROGRESS              1023
#define IDC_ADMINPASSWORD2              1023
#define IDC_PROCESORSTEXT               1023
#define IDC_BUILDDATETEXT               1024
#define IDC_SQLDRIVER                   1025
#define IDC_SQLDATABASE                 1026
#define IDC_BROWSEBUTTON                1026
#define IDC_SQLUSERNAME                 1027
#define IDC_SQLPASSWORD                 1028
#define IDC_TEMPDIR                     1029
#define IDC_VERSIONTAG                  1030
#define IDC_SQLSERVER                   1031
#define IDC_CHECK1                      1032
#define IDC_USENTFIBERS                 1032
#define IDC_STATICFRAME                 1038
#define IDC_CONNECTIONS                 1039
#define IDC_TOTALCONNECTS               1040
#define IDC_WARNINGS                    1041
#define IDC_ERRORS                      1042
#define IDC_CLIENTTHREADBOOST           3000
#define IDC_DROPBADPACKETS              3001
#define IDC_USEPACKEMODE                3002
#define IDC_PROCESSTBOOTS               4000
#define ID_SERVER_START                 40001
#define ID_SERVER_STOP                  40002
#define ID_SERVER_SETTINGS              40003
#define ID_SERVkkkSTOP                  40003
#define ID_MONITOR_CONNECTIONS          40005
#define ID_SERVER_CLOSE                 40006
#define ID_HELP_ABOUT                   40007
#define ID_REPLICATION_SETUPNEWDATABASE 40008
#define ID_SPECIAL_DEBUGMODE            40009
#define ID_SPECIAL_OPENCONSOLE          40010
#define ID_HELP_VERSION                 40011

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        103
#define _APS_NEXT_COMMAND_VALUE         40008
#define _APS_NEXT_CONTROL_VALUE         1010
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
